[−][src]Module bee_runtime::node
Traits used to represent bee nodes and allow for their instantiation.
Traits
| Node | A trait representing a node framework through which node workers may communicate. |
| NodeBuilder | A trait that provides generic build configuration capabilities for a node. |